@@ -89,7 +89,7 @@ class Trade(NamedTuple):
         exit_date: Exit date.
         shares: Number of shares.
         pnl: Profit and loss (PnL).
-        pnl_pct: Profit and loss (PnL), measured in percentage.
+        return_pct: Return measured in percentage.
         cumulative_pnl: Cumulative profit and loss (PnL) of the strategy after
             the trade.
         bars: Number of bars the trade was held.
@@ -103,7 +103,7 @@ class Trade(NamedTuple):
     exit_date: np.datetime64
     shares: int
     pnl: Decimal
-    pnl_pct: Decimal
+    return_pct: Decimal
     cumulative_pnl: Decimal
     bars: int
     pnl_per_bar: Decimal
@@ -120,7 +120,6 @@ class Order(NamedTuple):
         limit_price: Limit price that was used for the order.
         fill_price: Price that the order was filled at.
         shares: Number of shares bought or sold.
-        pnl: Realized profit and loss (PnL).
     """
 
     id: int
@@ -130,7 +129,6 @@ class Order(NamedTuple):
     limit_price: Optional[Decimal]
     fill_price: Decimal
     shares: int
-    pnl: Decimal
 
 
 class PortfolioBar(NamedTuple):
@@ -285,7 +283,6 @@ class Portfolio:
         limit_price: Optional[Decimal],
         fill_price: Decimal,
         shares: int,
-        pnl: Decimal,
     ) -> Order:
         self._order_id += 1
         order = Order(
@@ -296,7 +293,6 @@ class Portfolio:
             limit_price=limit_price,
             fill_price=fill_price,
             shares=shares,
-            pnl=pnl,
         )
         self.orders.append(order)
         return order
@@ -309,7 +305,7 @@ class Portfolio:
         exit_date: np.datetime64,
         shares: int,
         pnl: Decimal,
-        pnl_pct: Decimal,
+        return_pct: Decimal,
         cumulative_pnl: Decimal,
         bars: int,
         pnl_per_bar: Decimal,
@@ -323,7 +319,7 @@ class Portfolio:
             exit_date=exit_date,
             shares=shares,
             pnl=pnl,
-            pnl_pct=pnl_pct,
+            return_pct=return_pct,
             cumulative_pnl=cumulative_pnl,
             bars=bars,
             pnl_per_bar=pnl_per_bar,
@@ -374,7 +370,6 @@ class Portfolio:
             limit_price=limit_price,
             fill_price=fill_price,
             shares=covered.filled_shares + bought_shares,
-            pnl=covered.pnl,
         )
         return order
 
@@ -410,7 +405,7 @@ class Portfolio:
                     exit_date=date,
                     shares=entry.shares,
                     pnl=entry_pnl,
-                    pnl_pct=((entry.price / fill_price) - 1) * 100,
+                    return_pct=((entry.price / fill_price) - 1) * 100,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=entry_pnl / entry.bars,
@@ -512,7 +507,6 @@ class Portfolio:
             limit_price=limit_price,
             fill_price=fill_price,
             shares=sold.filled_shares + short_shares,
-            pnl=sold.pnl,
         )
         return order
 
@@ -546,7 +540,7 @@ class Portfolio:
                     exit_date=date,
                     shares=entry.shares,
                     pnl=entry_pnl,
-                    pnl_pct=((fill_price / entry.price) - 1) * 100,
+                    return_pct=((fill_price / entry.price) - 1) * 100,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=entry_pnl / entry.bars,
