@@ -1383,14 +1383,14 @@ class Strategy(
             orders, columns=Order._fields, index="id"
         )
         orders_df["shares"] = orders_df["shares"].astype(int)
-        for col in ("limit_price", "fill_price", "pnl"):
+        for col in ("limit_price", "fill_price"):
             orders_df[col] = quantize(orders_df, col)
         trades_df = pd.DataFrame.from_records(
             trades, columns=Trade._fields, index="id"
         )
         trades_df["shares"] = trades_df["shares"].astype(int)
         trades_df["bars"] = trades_df["bars"].astype(int)
-        for col in ("pnl", "pnl_pct", "cumulative_pnl", "pnl_per_bar"):
+        for col in ("pnl", "return_pct", "cumulative_pnl", "pnl_per_bar"):
             trades_df[col] = quantize(trades_df, col)
         eval_result = self.evaluate(
             portfolio_df=portfolio_df,
